use rocket::{
    fs::NamedFile,
    get,
    http::{ContentType, Status},
    State,
};

use crate::library::Library;

#[get("/video/raw?<v>")]
pub async fn video_file(v: &str, library: &State<Library>) -> Option<NamedFile> {
    let video = if let Some(video) = library.get_video_by_id(v).await {
        video
    } else {
        library.get_video_by_youtube_id(v).await.unwrap()
    };

    NamedFile::open(video.path).await.ok()
}

#[get("/video/thumbnail?<v>")]
pub async fn video_thumbnail(v: &str, library: &State<Library>) -> Option<NamedFile> {
    let video = if let Some(video) = library.get_video_by_id(v).await {
        video
    } else {
        library.get_video_by_youtube_id(v).await.unwrap()
    };

    let path = std::path::Path::new(&video.path);
    let parent = path.parent().unwrap();
    let thumbnail_path = path.file_stem().unwrap().to_str().unwrap();
    let thumbnail_path = parent.join(thumbnail_path);
    let thumbnail_path = thumbnail_path.to_str().unwrap();

    NamedFile::open(format!("{thumbnail_path}.jpg")).await.ok()
}

#[get("/favicon")]
pub async fn fav_icon() -> (Status, (ContentType, &'static [u8])) {
    (
        Status::Ok,
        (ContentType::PNG, include_bytes!("../../src/icon.png")),
    )
}
