use rocket::http::{ContentType, Status};

pub mod assets;
pub mod components;
pub mod index;
pub mod watch;
pub mod yt;

/// A trait to generate a Model API representation in JSON format.
pub trait ToAPI: Sized {
    /// Generate public API JSON
    fn api(&self) -> impl std::future::Future<Output = serde_json::Value>;
}

/// Converts a slice of items implementing the `ToAPI` trait into a `Vec` of JSON values.
pub async fn vec_to_api(items: &[impl ToAPI]) -> Vec<serde_json::Value> {
    let mut ret = Vec::with_capacity(items.len());

    for e in items {
        ret.push(e.api().await);
    }

    ret
}

pub fn api_response(json: &serde_json::Value) -> (Status, (ContentType, String)) {
    (
        Status::Ok,
        (ContentType::JSON, serde_json::to_string(json).unwrap()),
    )
}
